Simple Python Data
::::::::::::::::::

.. toctree::
   :caption: Simple Python Data
   :maxdepth: 2

   intro-VariablesExpressionsandStatements.rst
   ValuesandDataTypes.rst
   Typeconversionfunctions.rst
   Variables.rst
   VariableNamesandKeywords.rst
   StatementsandExpressions.rst
   OperatorsandOperands.rst
   Input.rst
   OrderofOperations.rst
   Reassignment.rst
   UpdatingVariables.rst
   Glossary.rst
   Exercises.rst
